## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

#
Name:           travelccm
Version:        1.00.11
Release:        %autorelease

Summary:        C++ Travel Customer Choice Model (CCM) Library

License:        LGPL-2.1-or-later
URL:            https://github.com/airsim/%{name}
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  soci-devel
BuildRequires:  soci-mysql-devel
BuildRequires:  soci-sqlite3-devel
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(stdair)

%description
%{name} aims at providing a clean API, and the corresponding
C++ implementation, for choosing one item among a set of travel
solutions, given demand-related characteristics (e.g.,
Willingness-To-Pay, preferred airline, preferred cabin, etc.).

The %{name} C++ library implements some simple Customer Choice Models
(CCM), as referenced in the literature (PhD dissertations at MIT, for
instance: https://dspace.mit.edu).

The %{name} C++ library exposes a simple, clean and object-oriented,
API. For instance, the choose() method takes, as input, both a
structure representing the travel request (e.g., "from Washington, DC,
US, to Beijing, China, on the 25th of May") and a list of travel
solutions (as provided by the Airline Travel Solution Provider (AirTSP)
project: https://github.com/airsim/airtsp), and yields, as output, the
chosen item.

The output can then be used by other systems, for instance to book the
corresponding travel or to visualize it on a map and calendar and to
share it with others.

%{name} makes an extensive use of existing open-source libraries for
increased functionality, speed and accuracy. In particular the
Boost (C++ Standard Extensions: https://www.boost.org) library is used.

Install the %{name} package if you need a library of basic C++ objects
for Customer-Choice Modeling (CCM), mainly for simulation purpose.

%package        devel
Summary:        Header files, libraries and development helper tools for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       pkgconfig

%description    devel
This package contains the header files, shared libraries and
development helper tools for %{name}. If you would like to develop
programs using %{name}, you will need to install %{name}-devel.

%package        doc
Summary:        HTML documentation for the %{name} library
BuildArch:      noarch
BuildRequires:  tex(latex)
BuildRequires:  texlive-epstopdf
BuildRequires:  doxygen
BuildRequires:  ghostscript

%description    doc
This package contains HTML pages, as well as a PDF reference manual,
for %{name}. All that documentation is generated thanks to Doxygen
(https://doxygen.org). The content is the same as what can be browsed
online (https://github.com/airsim/%{name}).


%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install

# Remove the installer generated by Doxygen
rm -f $RPM_BUILD_ROOT%{_docdir}/%{name}/html/installdox

# Remove additional documentation files (those files are already available
# in the project top directory)
rm -f $RPM_BUILD_ROOT%{_docdir}/%{name}/{NEWS,README.md,AUTHORS}

%check
%ctest


%files
%doc AUTHORS ChangeLog NEWS README.md
%license COPYING
%{_bindir}/%{name}
%{_libdir}/lib%{name}.so.*
%{_mandir}/man1/%{name}.1.*

%files devel
%license COPYING
%{_includedir}/%{name}/
%{_bindir}/%{name}-config
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}/
%{_datadir}/aclocal/%{name}.m4
%{_mandir}/man1/%{name}-config.1.*
%{_mandir}/man3/%{name}-library.3.*

%files doc
%doc %{_docdir}/%{name}/
%license COPYING


%changelog
## START: Generated by rpmautospec
* Tue May 06 2025 Pavol Sloboda <psloboda@redhat.com> - 1.00.11-2
- Removed the redundant BuildRequires of mysql-devel I have removed the
  redundant BuildRequires of mysql-devel as it is already uncoditionally
  required by soci-mysql-devel, which is in turn uncoditionally required by
  this package thus being available in the build chroot transitively.

* Mon Mar 31 2025 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.11-1
- Upstream upgrade

* Mon Jan 27 2025 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.10-1
- Upstream update

* Sun Jan 19 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Sat Jul 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sat Mar 23 2024 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.9-1
- Upstream upgrade

* Sat Jan 27 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.8-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Thu Jan 18 2024 Jonathan Wakely <jwakely@redhat.com> - 1.00.8-4
- Rebuilt for Boost 1.83

* Tue Nov 14 2023 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.8-3
- Modernized the spec file

* Sat Jul 22 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Mon May 01 2023 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.8-1
- Upstream upgrade

* Mon Feb 20 2023 Jonathan Wakely <jwakely@redhat.com> - 1.00.7-4
- Rebuilt for Boost 1.81

* Sat Jan 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sun Jul 10 2022 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.7-1
- Upgraded to v1.00.7

* Wed May 04 2022 Thomas Rodgers <trodgers@redhat.com> - 1.00.5-12
- Rebuilt for Boost 1.78

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.5-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Aug 07 2021 Jonathan Wakely <jwakely@redhat.com> - 1.00.5-10
- Rebuilt for Boost 1.76

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.5-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 22 2021 Jonathan Wakely <jwakely@redhat.com> - 1.00.5-7
- Rebuilt for Boost 1.75

* Sun Aug 09 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.5-6
- Removed the docdir work around (no longer needed)

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jul 18 2020 Igor Raits <ignatenkobrain@fedoraproject.org> - 1.00.5-4
- Improve compatibility with new CMake macro

* Sat Jun 06 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.5-3
- Rebuilt for SOCI 4.0.1-alpha2

* Wed Jun 03 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.5-2
- Rebuilt for Boost 1.73

* Sun May 31 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.5-1
- Upstream update

* Sun Feb 16 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.4-8
- Removed the python-abi problematic line

* Sun Feb 16 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.4-7
- Fixed Python3 macro expansion issue

* Sun Feb 16 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.4-6
- BZ#41324726 - fixed the FTBFS issue on armv7hl

* Fri Jan 31 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Aug 19 2019 Miro Hrončok <miro@hroncok.cz> - 1.00.4-4
- Rebuilt for Python 3.8

* Sat Jul 27 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Jul 12 2019 Miro Hrončok <miro@hroncok.cz> - 1.00.4-2
- Pin the Python version this was built with

* Thu Jul 11 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.4-1
- CMake support files updated for Python 3.8

* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jan 25 2019 Jonathan Wakely <jwakely@redhat.com> - 1.00.3-2
- Rebuilt for Boost 1.69

* Thu Jan 17 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.3-1
- Upstream update

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.2-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Jason Tibbitts <tibbs@math.uh.edu> - 1.00.2-19
- Remove needless use of %%defattr

* Mon Jul 09 2018 Igor Gnatenko <ignatenko@redhat.com> - 1.00.2-18
- add BuildRequires: gcc-c++

* Thu May 10 2018 Jonathan Wakely <jwakely@redhat.com> - 1.00.2-17
- Add BuildRequires: boost-python2-devel to fix build with
  boost-1.66.0-7.fc29

* Wed Feb 14 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.00.2-16
- Remove %%clean section

* Tue Feb 13 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.00.2-15
- Remove BuildRoot definition

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.2-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan 23 2018 Jonathan Wakely <jwakely@redhat.com> - 1.00.2-13
- Rebuilt for Boost 1.66

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.2-12
- Rebuilt for
  https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.2-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 24 2017 Björn Esser <besser82@fedoraproject.org> - 1.00.2-10
- Rebuilt for Boost 1.64

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan 12 2017 Igor Gnatenko <ignatenko@redhat.com> - 1.00.2-8
- Rebuild for readline 7.x

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Jan 18 2016 Jonathan Wakely <jwakely@redhat.com> - 1.00.2-6
- Rebuilt for Boost 1.60

* Sun Aug 30 2015 Jonathan Wakely <jwakely@redhat.com> - 1.00.2-5
- Patched and rebuilt for Boost 1.59

* Sat Aug 29 2015 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.2-4
- Mass rebuild

* Wed Jul 29 2015 Dennis Gilmore <dennis@ausil.us> - 1.00.2-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 1.00.2-2
- rebuild for Boost 1.58

* Sun Jun 21 2015 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.2-1
- Removed the dependency on ZeroMQ (only AirInv is dependent on it, not
  StdAir)

* Fri Jun 19 2015 Dennis Gilmore <dennis@ausil.us> - 1.00.1-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.00.1-12
- Rebuilt for GCC 5 C++11 ABI change

* Wed Jan 28 2015 Petr Machata <pmachata@redhat.com> - 1.00.1-11
- Cmake should look for zmq.h, not zmq.hpp

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 1.00.1-10
- Rebuild for boost 1.57.0

* Mon Aug 18 2014 Peter Robinson <pbrobinson@fedoraproject.org> - 1.00.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Dennis Gilmore <dennis@ausil.us> - 1.00.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 1.00.1-7
- rebuild for boost 1.55.0

* Sun Aug 04 2013 Dennis Gilmore <dennis@ausil.us> - 1.00.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 1.00.1-5
- Fix unversioned doc issue

* Sun Jul 28 2013 Petr Machata <pmachata@redhat.com> - 1.00.1-4
- Rebuild for boost 1.54.0

* Wed May 22 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.1-3
- Rebuild for Soci-3.2.1

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.1-2
- Rebuild for Boost-1.53.0

* Tue Dec 25 2012 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.1-1
- Upstream update

* Mon Aug 13 2012 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.5.3-4
- Rebuilt for new Boost 1.50.0.

* Sun Jul 22 2012 Dennis Gilmore <dennis@ausil.us> - 0.5.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Dennis Gilmore <dennis@ausil.us> - 0.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Dec 05 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.5.3-1
- Upstream update

* Sun Nov 20 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.5.2-3
- Rebuild for the new Boost-1.48.0

* Wed Nov 02 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.5.2-2
- [Sources] Uploaded the travelccm-0.5.2 tar-ball.

* Wed Nov 02 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.5.2-1
- Rebuilt for the new soci-3.1.0 and stdair-0.44.0 packages

* Sun Oct 16 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.5.0-2
- Rebuild for the new 0.43.0 version of the StdAir package

* Tue Oct 04 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.5.0-1
- Integrated feedback from review requests: #732218, #728649 and #702987
## END: Generated by rpmautospec
